Skip to contents

Returns a random big integer using the cryptographically secure generator from the sodium package.

Usage

random.bigz(nBits)

Arguments

nBits

number of bits, which must be a multiple of 8 (not checked, for efficiency).

Value

a gmp::bigz value.