Splits x into integer and fractional parts, encrypts each part as
a separate PaillierCiphertext, and packages the result as a
PaillierEncryptedReal so that later additions and subtractions can
be performed via R's arithmetic operators.
Splits x into integer and fractional parts, encrypts each part as
a separate PaillierCiphertext, and packages the result as a
PaillierEncryptedReal so that later additions and subtractions can
be performed via R's arithmetic operators.