R/homomorpheR.R
random.bigz.Rd
Returns a random big integer using the cryptographically secure generator from the sodium package.
sodium
random.bigz(nBits)
number of bits, which must be a multiple of 8 (not checked, for efficiency).
a gmp::bigz value.